/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.migration.modell.netz;

import de.bsvrz.ibv.simbaustelle.migration.modell.netz.NetzInterface.FahrtRichtung;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.Strasse;

/**
 * Rep&auml;sentiert eine Ortsreferenz, bei der die Ortsangabe über eine
 * Stra&szlig;e und den Betriebskilometer dargestellt wird.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */

public class StrasseUndBetriebsKilometerOrtsReferenz implements StrasseUndBetriebsKilometerOrtsReferenzInterface {

	/** Betriebskilometer auf der Stra&szlig;e in Metern. */
	private final long betriebsKilometer;

	/** Blocknummer des Betriebskilometers auf der Straße. */
	private final int blockNummer;

	/** Richtung auf dem Stra&szlig;enSegment. */
	private final NetzInterface.FahrtRichtung fahrtRichtung;

	/** Referenzierte Stra&szlig;e. */
	private final Strasse strasse;

	/**
	 * Erzeugt eine Ortsreferenz, bei der die Ortsangabe &uuml;ber eine
	 * Stra&szlig;e und den Betriebskilometer dargestellt wird.
	 *
	 * @param strasse
	 *            Referenzierte Stra&szlig;e
	 * @param fahrtRichtung
	 *            Richtung auf dem Stra&szlig;enSegment
	 * @param betriebsKilometer
	 *            Betriebskilometer auf der Stra&szlig;e in Metern
	 * @param blockNummer
	 *            Blocknummer des Betriebskilometers auf der Stra&szlig;e
	 */
	public StrasseUndBetriebsKilometerOrtsReferenz(final Strasse strasse, final FahrtRichtung fahrtRichtung,
			final long betriebsKilometer, final int blockNummer) {

		if (strasse == null) {
			throw new IllegalArgumentException("Die Strasse darf nicht 'null' sein");
		}

		this.betriebsKilometer = betriebsKilometer;
		this.blockNummer = blockNummer;
		this.fahrtRichtung = fahrtRichtung;
		this.strasse = strasse;
	}

	@Override
	public StrassenSegmentUndOffsetOrtsReferenzInterface ermittleOrtsReferenzStrassenSegmentUndOffset()
			throws NetzReferenzException {
		return NetzReferenzen.getInstanz().ermittleOrtsReferenzStrassenSegmentUndOffset(this);
	}

	@Override
	public long getBetriebsKilometer() {
		return betriebsKilometer;
	}

	@Override
	public int getBlockNummer() {
		return blockNummer;
	}

	@Override
	public FahrtRichtung getFahrtRichtung() {
		return fahrtRichtung;
	}

	@Override
	public Strasse getStrasse() {
		return strasse;
	}
}
