/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.simbaustelle;

/**
 * Definition der Konstanten für die Kommunikation der Baustellensimulation mit
 * dem Datenverteiler.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class BssKonstanten {

	/**
	 * der Name des Attributs zur Definition des Prognosehorizonts.
	 */
	public static final String PARAM_NAME_PROGNOSE_HORIZONT = "PrognoseHorizont";

	/**
	 * der Faktor Q0 für die Berücksichtigung des Fundamentaldiagramms bei der
	 * Simulation des Stauverlaufs.
	 */
	public static final String PARAM_NAME_FAKTOR_Q0 = "FaktorQ0";
	/**
	 * der Name des Attributs zur Definition der durchschnittlichen Länge eines
	 * Fahrzeuges im Stau.
	 */
	public static final String PARAM_NAME_LAENGE_PKW = "LängePkw";
	/**
	 * der Name des Attributs zur Definition der Schrittweite der Iteration bei
	 * der Stauberechnung.
	 */
	public static final String PARAM_NAME_ITERATIONS_SCHRITTWEITE = "IterationsSchrittweite";
	/**
	 * der Name des Attributs zur Definition der Länge, bei der ein neuer Stau
	 * in den Prognosedaten angelegt wird.
	 */
	public static final String PARAM_NAME_LAENGE_STAU_BEGINN = "LängeStauBeginn";
	/**
	 * der Name des Attributs zur Definition der Länge, bei der ein aktuell in
	 * der Prognose vorliegender Stau beendet wird.
	 */
	public static final String PARAM_NAME_LAENGE_STAU_AUFHEBUNG = "LängeStauAufhebung";
	/**
	 * die PID der Attributgruppe zur Definition der
	 * Baustellensimulationsparameter.
	 */
	public static final String PID_ATG_BAUSTELLEN_SIMULATION_MODELL = "atg.baustellenSimulationModell";
	/**
	 * die PID der Attributgruppe, in der die Ergebnisse der
	 * Baustellensimulation veröffentlicht werden.
	 */
	public static final String PID_ATG_FUNDAMENTAL_DIAGRAMM = "atg.fundamentalDiagramm";
	/**
	 * der Name des Feldes, das die ermittelten Staus enthält.
	 */
	public static final String ATT_NAME_FELD_BAUSTELLEN_SIMULATION = "BaustellenSimulation";
	/**
	 * der Name des Attributs zum Ablegen der maximalen Verlustzeit innerhalb
	 * eines prognostizierten Staus.
	 */
	public static final String ATT_NAME_VERLUST_ZEIT = "VerlustZeit";
	/**
	 * der Name des Attributs zum Ablegen des Zeitpunkts der maximalen
	 * Ausdehnungen innerhalb eines prognostizierten Staus.
	 */
	public static final String ATT_NAME_MAX_LAENGE_ZEIT = "MaxLängeZeit";
	/**
	 * der Name des Attributs zum Ablegen der maximalen Ausdehnungen innerhalb
	 * eines prognostizierten Staus.
	 */
	public static final String ATT_NAME_MAX_LAENGE = "MaxLänge";
	/**
	 * der Name des Attributs zum Ablegen der Dauer eines prognostizierten
	 * Staus.
	 */
	public static final String ATT_NAME_DAUER = "Dauer";
	/**
	 * der Name des Attributs zum Ablegen des Anfangszeitpunktes eines
	 * prognostizierten Staus.
	 */
	public static final String ATT_NAME_START_ZEIT = "StartZeit";
	/**
	 * der Name des Attributs mit dem Q0-Wert des Fundamentaldiagramms eines
	 * Messquerschnitts. Der Wert wird für die Prognose der Staus innerhalb der
	 * Baustelle benötigt.
	 */
	public static final String ATT_NAME_Q0 = "Q0";

	/**
	 * PID des Apekts unter dem die prognostizierten Staus einer Baustelle
	 * veröffentlicht werden.
	 */
	public static final String PID_ASP_PROGNOSE_NORMAL = "asp.prognoseNormal";

	/**
	 * PID der Attributgruppe über die die prognostizierten Staus einer
	 * Baustelle veröffentlicht werden.
	 */
	public static final String PID_ATG_BAUSTELLEN_SIMULATION = "atg.baustellenSimulation";

	/**
	 * PID der Attributgruppe mit den Eigenschaften einer Baustelle innerhalb
	 * des Datenverteilers.
	 */
	public static final String PID_ATG_BAUSTELLEN_EIGENSCHAFTEN = "atg.baustellenEigenschaften";

	/**
	 * PID der Attributgruppe mit den Eigenschaften einer Situation innerhalb
	 * des Datenverteilers.
	 */
	public static final String PID_ATG_SITUATIONS_EIGENSCHAFTEN = "atg.situationsEigenschaften";

	/**
	 * Name des Attributes mit dem Anfangszeitpunkt einer Situation.
	 */
	public static final String ATT_NAME_SITUATION_START_ZEIT = "StartZeit";

	/**
	 * Name des Attributes mit der Dauer einer Situation.
	 */
	public static final String ATT_NAME_SITUATION_DAUER = "Dauer";

	/**
	 * Name des Attributes mit der Definition der Restkapazität einer Baustelle.
	 */
	public static final String ATT_NAME_BST_REST_KAPAZITAET = "RestKapazität";

	/**
	 * Name des Attributes mit dem Status einer Baustelle.
	 */
	public static final String ATT_NAME_BST_STATUS = "Status";

	/**
	 * Name des Attributes mit der Liste der Straßensegmente, auf denen sich
	 * eine Sitaution ausbreitet.
	 */
	public static final String ATT_NAME_SITUATION_STRASSEN_SEGMENT = "StraßenSegment";

	/**
	 * Name des Attributes mit dem Abstand des Endes der Ausbreitung einer
	 * Situation bis zum Ende des letzten beteiligten Straßensegmentes.
	 */
	public static final String ATT_NAME_SITUATION_END_OFFSET = "EndOffset";

	/**
	 * PID des Aspekts, unter dem die Aufforderung für die manuelle Simulation
	 * einer Baustelle empfangen wird.
	 */
	public static final String PID_ASP_SENDEN = "asp.senden";

	/**
	 * PID der Attributgruppe mit den Daten für die manuelle Simulation einer
	 * Baustelle.
	 */
	public static final String PID_ATG_BAUSTELLEN_SIMULATION_STARTEN = "atg.baustellenSimulationStarten";

	/**
	 * PID der Attributgruppe mit den Daten für die manuelle Simulation einer
	 * Baustelle.
	 */
	public static final String PID_ATG_BAUSTELLEN_SIMULATION_STARTEN_MIT_MQ = "atg.baustellenSimulationStartenMitMq";

	/**
	 * Name des Attributs, in dem bei einer manuellen Simulationsanforderung der
	 * Name des Auftragsgebers übermittelt wird.
	 */
	public static final String ATT_NAME_SIMSTART_BEMERKUNG = "Bemerkung";

	/**
	 * Name des Attributs, in dem bei einer manuellen Simulationsanforderung der
	 * MQ vor der Baustelle übermittelt wird.
	 */
	public static final String ATT_NAME_SIMSTART_BERECHNUNGS_MQ = "BerechnungsMQ";

	/**
	 * Name des Attributs, in dem bei einer manuellen Simulationsanforderung die
	 * Beschreibung des Auftrags übermittelt wird.
	 */
	public static final String ATT_NAME_SIMSTART_NAME = "Name";

	/**
	 * Name des Feldes, in dem die Baustellenobjekte eines VerkehrsModellNetz
	 * abgelegt sind.
	 */
	public static final String ATT_NAME_FELD_NETZ_BAUSTELLEN = "Baustellen";

	/** privater Konstruktor. */
	private BssKonstanten() {
		super();
	}
}
