/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.verwaltung;

import java.time.LocalDateTime;
import java.util.List;

import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.StrassenSegment;
import de.bsvrz.ibv.simbaustelle.migration.util.UndefiniertException;

/**
 * Schnittstelle für Objekte, die die konfigurierenden und parametrierten einer
 * Baustelle für die Baustellensimulation zur Verfügung stellen.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface BaustellenDatenSchnittstelle {

	/**
	 * liefert den geplanten Startzeitpunkt der Baustelle.
	 *
	 * @return den Zeitpunkt
	 * @throws UndefiniertException
	 *             der Zeitpunkt konnte nicht ermittelt werden, weil der
	 *             Parameterdatensatz nicht vorliegt oder dieser den
	 *             Startzeitpunkt nicht enthält
	 *             
	 *             // TODO LocalDateTime
	 *             
	 */
	LocalDateTime getStart() throws UndefiniertException;

	/**
	 * liefert den geplanten Endzeitpunkt der Baustelle.
	 *
	 * @return den Zeitpunkt
	 * @throws UndefiniertException
	 *             der Zeitpunkt konnte nicht ermittelt werden, weil der
	 *             Parameterdatensatz nicht vorliegt oder dieser den
	 *             Startzeitpunkt nicht enthält
	 */
	LocalDateTime getEnde() throws UndefiniertException;

	/**
	 * liefert die Engpasskapazität für den gegebenen Zeitpunkt in Fz/h.
	 *
	 * @param zs
	 *            der Zeitpunkt
	 * @return die Kapazität
	 * @throws UndefiniertException
	 *             die Restkapazität konnte nicht ermittelt werden, weil nicht
	 *             alle dafür notwendigen Informationen zur Verfügung standen
	 */
	long getRestKapazitaet(LocalDateTime zs) throws UndefiniertException;

	/**
	 * liefert den parametrierten Endoffset relativ zum Ende der innerhalb des
	 * letzten Straßensegments.
	 *
	 * @return den Offset
	 * @throws UndefiniertException
	 *             der Wert konnte nicht ermittelt werden, weil der
	 *             entsprechende Parameterdatensatz nicht zur Verfügung steht.
	 */
	long getEndOffset() throws UndefiniertException;

	/**
	 * liefert die Liste der Strassensegmente auf denen die Baustelle liegt.
	 *
	 * @return die Liste der Segment
	 * @throws UndefiniertException
	 *             es konnten keine Segmente ermittelt werden, weil der
	 *             Parameterdatensatz nicht vorlag oder der Parameterdatensatz
	 *             keine Segmente enthält
	 */
	List<StrassenSegment> getSegmente() throws UndefiniertException;
	
	void disconnect();

}
